Aggravate a monster if a flirt or gift was unsuccessful.
[rogue-pphs.git] / command.c
index 6b8033b..584ba8a 100644 (file)
--- a/command.c
+++ b/command.c
@@ -3,7 +3,7 @@
  *\r
  * @(#)command.c       3.45 (Berkeley) 6/15/81\r
  *\r
* Rogue: Exploring the Dungeons of Doom\r
  * Copyright (C) 1980, 1981 Michael Toy, Ken Arnold and Glenn Wichman\r
  * All rights reserved.\r
  *\r
@@ -101,26 +101,6 @@ command()
                        count = 0;\r
                }\r
            }\r
-           switch (ch)\r
-           {\r
-               case 'f':\r
-                   if (!on(player, ISBLIND))\r
-                   {\r
-                       door_stop = TRUE;\r
-                       firstmove = TRUE;\r
-                   }\r
-                   if (count && !newcount)\r
-                       ch = direction;\r
-                   else\r
-                       ch = readchar(cw);\r
-                   switch (ch)\r
-                   {\r
-                       case 'h': case 'j': case 'k': case 'l':\r
-                       case 'y': case 'u': case 'b': case 'n':\r
-                           ch = toupper(ch);\r
-                   }\r
-                   direction = ch;\r
-           }\r
            newcount = FALSE;\r
            /*\r
             * execute a command\r
@@ -165,6 +145,18 @@ command()
                when 'R' : ring_off();\r
                when 'o' : option();\r
                when 'c' : call();\r
+                when 'f':\r
+                   if (!get_dir())\r
+                       after = FALSE;\r
+                   else\r
+                       flirt(delta.y, delta.x);\r
+                when 'g':\r
+                   if (!get_dir())\r
+                       after = FALSE;\r
+                   else\r
+                       gift(delta.y, delta.x);\r
+                when 'E':\r
+                    embrace();\r
                when '>' : after = FALSE; d_level();\r
                when '<' : after = FALSE; u_level();\r
                when '?' : after = FALSE; help();\r
@@ -201,7 +193,7 @@ command()
                    {\r
                        if (wizard = passwd())\r
                        {\r
-                           msg("You are suddenly as smart as Ken Arnold in dungeon #%d", dnum);\r
+                           msg("You are suddenly as smart as Ken Arnold in cavern #%d", dnum);\r
                            wizard = TRUE;\r
                            waswizard = TRUE;\r
                        }\r
@@ -526,7 +518,7 @@ u_level()
        {\r
            level--;\r
            if (level == 0)\r
-               total_winner();\r
+               total_loner();\r
            new_level();\r
            msg("You feel a wrenching sensation in your gut.");\r
            return;\r
@@ -3,7 +3,7 @@
  * @(#)command.c       3.45 (Berkeley) 6/15/81\r
  *\r
- * Rogue: Exploring the Dungeons of Doom\r
+ * Rogue: Exploring the Cavern of Cuties\r
  * Copyright (C) 1980, 1981 Michael Toy, Ken Arnold and Glenn Wichman\r
  * All rights reserved.\r